pub struct AdminSnapshotSummary {
pub summary: SnapshotSummary,
pub tenant_id: String,
pub project_id: String,
}Expand description
Same shape as the tenant listing plus the scope a platform operator needs in order to tell two tenants’ snapshots apart.
Fields
summary: SnapshotSummarytenant_id: Stringproject_id: StringTrait Implementations
Sourceimpl Clone for AdminSnapshotSummary
impl Clone for AdminSnapshotSummary
Sourcefn clone(&self) -> AdminSnapshotSummary
fn clone(&self) -> AdminSnapshotSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminSnapshotSummary
impl Debug for AdminSnapshotSummary
Sourceimpl<'de> Deserialize<'de> for AdminSnapshotSummary
impl<'de> Deserialize<'de> for AdminSnapshotSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AdminSnapshotSummary
impl PartialEq for AdminSnapshotSummary
Sourceimpl Serialize for AdminSnapshotSummary
impl Serialize for AdminSnapshotSummary
impl StructuralPartialEq for AdminSnapshotSummary