pub struct SnapshotBundle {
pub schema_version: u32,
pub snapshots: Vec<EvalSnapshot>,
pub exported_at_ms: i64,
}Expand description
Portable bundle used to move builtin snapshots between Infra deployments. Import is an idempotent replay keyed on the digest.
Fields
schema_version: u32snapshots: Vec<EvalSnapshot>exported_at_ms: i64Trait Implementations
Sourceimpl Clone for SnapshotBundle
impl Clone for SnapshotBundle
Sourcefn clone(&self) -> SnapshotBundle
fn clone(&self) -> SnapshotBundle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotBundle
impl Debug for SnapshotBundle
Sourceimpl<'de> Deserialize<'de> for SnapshotBundle
impl<'de> Deserialize<'de> for SnapshotBundle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SnapshotBundle
impl PartialEq for SnapshotBundle
Sourceimpl Serialize for SnapshotBundle
impl Serialize for SnapshotBundle
impl StructuralPartialEq for SnapshotBundle